import { AuthResponse } from "../models/authResponse";
import { Endpoint } from "../models/endpoint";
import { Request } from "../models/request";
export declare const authRoutesPropertyName = "authRoutes";
export declare const noAuthRoutesPropertyName = "noAuthRoutes";
export declare const controllerLevelAuthPropertyName = "controllerAuth";
/**
 * Specifies that a controller method is to be authenticated and authorized.
 * @param authCallback Method to call while performing authentication and authorization on this route.
 * This callback is optional and if not provided, the callback provided in the `@ControllerAuth` decorator (if used) will be used,
 * otherwise, `bootstrap` function's callback will be used.
 */
export declare function Auth(authCallback?: (req: Request, endpoint: Endpoint) => AuthResponse): (target: any, propertyKey: string) => void;
/**
 * Specifies that a controller method is excluded from authentication and authorization.
 * Useful when the controller is marked with `@ControllerAuth` decorator.
 */
export declare function NoAuth(): (target: any, propertyKey: string) => void;
/**
 * Specifies that all the routes/method of a controller are to be authenticated and authorized.
 * @param authCallback Method to call while performing authentication and authorization on the routes of this method.
 * This callback is optional and if not provided, the callback provided in `bootstrap` function will be used.
 */
export declare function ControllerAuth(authCallback?: (req: Request, endpoint: Endpoint) => AuthResponse): <T extends new (...args: any[]) => {}>(constructor: T) => T;
